declare module "windows.networking.networkoperators" {
  export class ProfileUsage {
    usageInMegabytes: Number;
    lastSyncTime: Date;
    constructor();
  }

  export enum DataClasses {
    none,
    gprs,
    edge,
    umts,
    hsdpa,
    hsupa,
    lteAdvanced,
    cdma1xRtt,
    cdma1xEvdo,
    cdma1xEvdoRevA,
    cdma1xEvdv,
    cdma3xRtt,
    cdma1xEvdoRevB,
    cdmaUmb,
    custom,
  }

  export enum MobileBroadbandDeviceType {
    unknown,
    embedded,
    removable,
    remote,
  }

  export enum NetworkDeviceStatus {
    deviceNotReady,
    deviceReady,
    simNotInserted,
    badSim,
    deviceHardwareFailure,
    accountNotActivated,
    deviceLocked,
    deviceBlocked,
  }

  export enum NetworkRegistrationState {
    none,
    deregistered,
    searching,
    home,
    roaming,
    partner,
    denied,
  }

  export enum MobileBroadbandRadioState {
    off,
    on,
  }

  export enum NetworkOperatorEventMessageType {
    gsm,
    cdma,
    ussd,
    dataPlanThresholdReached,
    dataPlanReset,
    dataPlanDeleted,
    profileConnected,
    profileDisconnected,
    registeredRoaming,
    registeredHome,
    tetheringEntitlementCheck,
    tetheringOperationalStateChanged,
    tetheringNumberOfClientsChanged,
  }

  export enum MobileBroadbandAccountWatcherStatus {
    created,
    started,
    enumerationCompleted,
    stopped,
    aborted,
  }

  export enum TetheringOperationalState {
    unknown,
    on,
    off,
    inTransition,
  }

  export enum TetheringCapability {
    enabled,
    disabledByGroupPolicy,
    disabledByHardwareLimitation,
    disabledByOperator,
    disabledBySku,
    disabledByRequiredAppNotInstalled,
    disabledDueToUnknownCause,
  }

  export enum TetheringOperationStatus {
    success,
    unknown,
    mobileBroadbandDeviceOff,
    wiFiDeviceOff,
    entitlementCheckTimeout,
    entitlementCheckFailure,
    operationInProgress,
  }

  export enum HotspotAuthenticationResponseCode {
    noError,
    loginSucceeded,
    loginFailed,
    radiusServerError,
    networkAdministratorError,
    loginAborted,
    accessGatewayInternalError,
  }

  export enum ProfileMediaType {
    wlan,
    wwan,
  }

  export enum UssdResultCode {
    noActionRequired,
    actionRequired,
    terminated,
    otherLocalClient,
    operationNotSupported,
    networkTimeout,
  }

  export class MobileBroadbandAccount {
    static availableNetworkAccountIds: Object;
    currentDeviceInformation: MobileBroadbandDeviceInformation;
    currentNetwork: MobileBroadbandNetwork;
    networkAccountId: String;
    serviceProviderGuid: String;
    serviceProviderName: String;
    constructor();

    static createFromNetworkAccountId(networkAccountId: String): MobileBroadbandAccount;


    getConnectionProfiles(): Object;

  }

  export class MobileBroadbandNetwork {
    accessPointName: String;
    activationNetworkError: Number;
    networkAdapter: Object;
    networkRegistrationState: NetworkRegistrationState;
    packetAttachNetworkError: Number;
    registeredDataClass: DataClasses;
    registeredProviderId: String;
    registeredProviderName: String;
    registrationNetworkError: Number;
    constructor();

    showConnectionUI(): void;

  }

  export class MobileBroadbandDeviceInformation {
    cellularClass: Number;
    currentRadioState: MobileBroadbandRadioState;
    customDataClass: String;
    dataClasses: DataClasses;
    deviceId: String;
    deviceType: MobileBroadbandDeviceType;
    firmwareInformation: String;
    manufacturer: String;
    mobileEquipmentId: String;
    model: String;
    networkDeviceStatus: NetworkDeviceStatus;
    simIccId: String;
    subscriberId: String;
    telephoneNumbers: Object;
    constructor();

  }

  export class NetworkOperatorNotificationEventDetails {
    encodingType: Number;
    message: String;
    networkAccountId: String;
    notificationType: NetworkOperatorEventMessageType;
    ruleId: String;
    smsMessage: Object;
    constructor();

    authorizeTethering(allow: Boolean, entitlementFailureReason: String): void;

  }

  export class NetworkOperatorTetheringAccessPointConfiguration {
    ssid: String;
    passphrase: String;
    constructor();

  }

  export class NetworkOperatorTetheringOperationResult {
    additionalErrorMessage: String;
    status: TetheringOperationStatus;
    constructor();

  }

  export class NetworkOperatorTetheringManager {
    clientCount: Number;
    maxClientCount: Number;
    tetheringOperationalState: TetheringOperationalState;
    constructor();

    static getTetheringCapability(networkAccountId: String): TetheringCapability;


    static createFromNetworkAccountId(networkAccountId: String): NetworkOperatorTetheringManager;


    configureAccessPointAsync(configuration: NetworkOperatorTetheringAccessPointConfiguration, callback: (error: Error) => void): void ;

    startTetheringAsync(callback: (error: Error, result: NetworkOperatorTetheringOperationResult) => void): void ;

    stopTetheringAsync(callback: (error: Error, result: NetworkOperatorTetheringOperationResult) => void): void ;

    getCurrentAccessPointConfiguration(): NetworkOperatorTetheringAccessPointConfiguration;

  }

  export class MobileBroadbandAccountEventArgs {
    networkAccountId: String;
    constructor();

  }

  export class MobileBroadbandAccountUpdatedEventArgs {
    hasDeviceInformationChanged: Boolean;
    hasNetworkChanged: Boolean;
    networkAccountId: String;
    constructor();

  }

  export class MobileBroadbandAccountWatcher {
    status: MobileBroadbandAccountWatcherStatus;
    constructor();

    start(): void;

    stop(): void;

    addListener(type: "AccountAdded", listener: (ev: Event) => void): void ;
    removeListener(type: "AccountAdded", listener: (ev: Event) => void): void ;
    on(type: "AccountAdded", listener: (ev: Event) => void): void ;
    off(type: "AccountAdded", listener: (ev: Event) => void): void ;
    
    addListener(type: "AccountRemoved", listener: (ev: Event) => void): void ;
    removeListener(type: "AccountRemoved", listener: (ev: Event) => void): void ;
    on(type: "AccountRemoved", listener: (ev: Event) => void): void ;
    off(type: "AccountRemoved", listener: (ev: Event) => void): void ;
    
    addListener(type: "AccountUpdated", listener: (ev: Event) => void): void ;
    removeListener(type: "AccountUpdated", listener: (ev: Event) => void): void ;
    on(type: "AccountUpdated", listener: (ev: Event) => void): void ;
    off(type: "AccountUpdated", listener: (ev: Event) => void): void ;
    
    addListener(type: "EnumerationCompleted", listener: (ev: Event) => void): void ;
    removeListener(type: "EnumerationCompleted", listener: (ev: Event) => void): void ;
    on(type: "EnumerationCompleted", listener: (ev: Event) => void): void ;
    off(type: "EnumerationCompleted", listener: (ev: Event) => void): void ;
    
    addListener(type: "Stopped", listener: (ev: Event) => void): void ;
    removeListener(type: "Stopped", listener: (ev: Event) => void): void ;
    on(type: "Stopped", listener: (ev: Event) => void): void ;
    off(type: "Stopped", listener: (ev: Event) => void): void ;
    
    addListener(type: string, listener: (ev: Event) => void): void ;
    removeListener(type: string, listener: (ev: Event) => void): void ;
    on(type: string, listener: (ev: Event) => void): void ;
    off(type: string, listener: (ev: Event) => void): void ;
    

  }

  export class HotspotAuthenticationEventDetails {
    eventToken: String;
    constructor();

  }

  export class HotspotAuthenticationContext {
    authenticationUrl: Object;
    networkAdapter: Object;
    redirectMessageUrl: Object;
    redirectMessageXml: Object;
    wirelessNetworkId: Array<Number>;
    constructor();

    static tryGetAuthenticationContext(evenToken: String, context: Object): Boolean;


    issueCredentialsAsync(userName: String, password: String, extraParameters: String, markAsManualConnectOnFailure: Boolean, callback: (error: Error, result: HotspotCredentialsAuthenticationResult) => void): void ;

    issueCredentials(userName: String, password: String, extraParameters: String, markAsManualConnectOnFailure: Boolean): void;

    abortAuthentication(markAsManual: Boolean): void;

    skipAuthentication(): void;

    triggerAttentionRequired(packageRelativeApplicationId: String, applicationParameters: String): void;

  }

  export class HotspotCredentialsAuthenticationResult {
    authenticationReplyXml: Object;
    hasNetworkErrorOccurred: Boolean;
    logoffUrl: Object;
    responseCode: HotspotAuthenticationResponseCode;
    constructor();

  }

  export class ProvisionFromXmlDocumentResults {
    allElementsProvisioned: Boolean;
    provisionResultsXml: String;
    constructor();

  }

  export class ProvisionedProfile {
    constructor();

    updateCost(value: Number): void;

    updateUsage(value: ProfileUsage): void;

  }

  export class ProvisioningAgent {
    constructor();

    static createFromNetworkAccountId(networkAccountId: String): ProvisioningAgent;


    provisionFromXmlDocumentAsync(provisioningXmlDocument: String, callback: (error: Error, result: ProvisionFromXmlDocumentResults) => void): void ;

    getProvisionedProfile(mediaType: ProfileMediaType, profileName: String): ProvisionedProfile;

  }

  export class UssdMessage {
    payloadAsText: String;
    dataCodingScheme: Number;
    constructor();
    constructor(messageText: String);

    getPayload(): Array<Number>;

    setPayload(value: Array<Number>): void;

  }

  export class UssdReply {
    message: UssdMessage;
    resultCode: UssdResultCode;
    constructor();

  }

  export class UssdSession {
    constructor();

    static createFromNetworkAccountId(networkAccountId: String): UssdSession;


    static createFromNetworkInterfaceId(networkInterfaceId: String): UssdSession;


    sendMessageAndGetReplyAsync(message: UssdMessage, callback: (error: Error, result: UssdReply) => void): void ;

    close(): void;

  }

}



