// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace Networking { namespace NetworkOperators { 
  v8::Handle<v8::Value> WrapMobileBroadbandAccount(::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ UnwrapMobileBroadbandAccount(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapMobileBroadbandNetwork(::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ UnwrapMobileBroadbandNetwork(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapMobileBroadbandDeviceInformation(::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ UnwrapMobileBroadbandDeviceInformation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapNetworkOperatorNotificationEventDetails(::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ UnwrapNetworkOperatorNotificationEventDetails(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapNetworkOperatorTetheringAccessPointConfiguration(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ UnwrapNetworkOperatorTetheringAccessPointConfiguration(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapNetworkOperatorTetheringOperationResult(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ UnwrapNetworkOperatorTetheringOperationResult(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapNetworkOperatorTetheringManager(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ UnwrapNetworkOperatorTetheringManager(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapMobileBroadbandAccountEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ UnwrapMobileBroadbandAccountEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapMobileBroadbandAccountUpdatedEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ UnwrapMobileBroadbandAccountUpdatedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapMobileBroadbandAccountWatcher(::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ UnwrapMobileBroadbandAccountWatcher(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapHotspotAuthenticationEventDetails(::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ UnwrapHotspotAuthenticationEventDetails(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapHotspotAuthenticationContext(::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ UnwrapHotspotAuthenticationContext(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapHotspotCredentialsAuthenticationResult(::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ UnwrapHotspotCredentialsAuthenticationResult(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapProvisionFromXmlDocumentResults(::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ UnwrapProvisionFromXmlDocumentResults(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapProvisionedProfile(::Windows::Networking::NetworkOperators::ProvisionedProfile^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::ProvisionedProfile^ UnwrapProvisionedProfile(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapProvisioningAgent(::Windows::Networking::NetworkOperators::ProvisioningAgent^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::ProvisioningAgent^ UnwrapProvisioningAgent(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapUssdMessage(::Windows::Networking::NetworkOperators::UssdMessage^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::UssdMessage^ UnwrapUssdMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapUssdReply(::Windows::Networking::NetworkOperators::UssdReply^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::UssdReply^ UnwrapUssdReply(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapUssdSession(::Windows::Networking::NetworkOperators::UssdSession^ wintRtInstance);
  ::Windows::Networking::NetworkOperators::UssdSession^ UnwrapUssdSession(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitDataClassesEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("DataClasses"), enumObject);

    enumObject->Set(String::NewSymbol("none"), Integer::New(0));
    enumObject->Set(String::NewSymbol("gprs"), Integer::New(1));
    enumObject->Set(String::NewSymbol("edge"), Integer::New(2));
    enumObject->Set(String::NewSymbol("umts"), Integer::New(3));
    enumObject->Set(String::NewSymbol("hsdpa"), Integer::New(4));
    enumObject->Set(String::NewSymbol("hsupa"), Integer::New(5));
    enumObject->Set(String::NewSymbol("lteAdvanced"), Integer::New(6));
    enumObject->Set(String::NewSymbol("cdma1xRtt"), Integer::New(7));
    enumObject->Set(String::NewSymbol("cdma1xEvdo"), Integer::New(8));
    enumObject->Set(String::NewSymbol("cdma1xEvdoRevA"), Integer::New(9));
    enumObject->Set(String::NewSymbol("cdma1xEvdv"), Integer::New(10));
    enumObject->Set(String::NewSymbol("cdma3xRtt"), Integer::New(11));
    enumObject->Set(String::NewSymbol("cdma1xEvdoRevB"), Integer::New(12));
    enumObject->Set(String::NewSymbol("cdmaUmb"), Integer::New(13));
    enumObject->Set(String::NewSymbol("custom"), Integer::New(14));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitMobileBroadbandDeviceTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("MobileBroadbandDeviceType"), enumObject);

    enumObject->Set(String::NewSymbol("unknown"), Integer::New(0));
    enumObject->Set(String::NewSymbol("embedded"), Integer::New(1));
    enumObject->Set(String::NewSymbol("removable"), Integer::New(2));
    enumObject->Set(String::NewSymbol("remote"), Integer::New(3));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitNetworkDeviceStatusEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("NetworkDeviceStatus"), enumObject);

    enumObject->Set(String::NewSymbol("deviceNotReady"), Integer::New(0));
    enumObject->Set(String::NewSymbol("deviceReady"), Integer::New(1));
    enumObject->Set(String::NewSymbol("simNotInserted"), Integer::New(2));
    enumObject->Set(String::NewSymbol("badSim"), Integer::New(3));
    enumObject->Set(String::NewSymbol("deviceHardwareFailure"), Integer::New(4));
    enumObject->Set(String::NewSymbol("accountNotActivated"), Integer::New(5));
    enumObject->Set(String::NewSymbol("deviceLocked"), Integer::New(6));
    enumObject->Set(String::NewSymbol("deviceBlocked"), Integer::New(7));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitNetworkRegistrationStateEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("NetworkRegistrationState"), enumObject);

    enumObject->Set(String::NewSymbol("none"), Integer::New(0));
    enumObject->Set(String::NewSymbol("deregistered"), Integer::New(1));
    enumObject->Set(String::NewSymbol("searching"), Integer::New(2));
    enumObject->Set(String::NewSymbol("home"), Integer::New(3));
    enumObject->Set(String::NewSymbol("roaming"), Integer::New(4));
    enumObject->Set(String::NewSymbol("partner"), Integer::New(5));
    enumObject->Set(String::NewSymbol("denied"), Integer::New(6));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitMobileBroadbandRadioStateEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("MobileBroadbandRadioState"), enumObject);

    enumObject->Set(String::NewSymbol("off"), Integer::New(0));
    enumObject->Set(String::NewSymbol("on"), Integer::New(1));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitNetworkOperatorEventMessageTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("NetworkOperatorEventMessageType"), enumObject);

    enumObject->Set(String::NewSymbol("gsm"), Integer::New(0));
    enumObject->Set(String::NewSymbol("cdma"), Integer::New(1));
    enumObject->Set(String::NewSymbol("ussd"), Integer::New(2));
    enumObject->Set(String::NewSymbol("dataPlanThresholdReached"), Integer::New(3));
    enumObject->Set(String::NewSymbol("dataPlanReset"), Integer::New(4));
    enumObject->Set(String::NewSymbol("dataPlanDeleted"), Integer::New(5));
    enumObject->Set(String::NewSymbol("profileConnected"), Integer::New(6));
    enumObject->Set(String::NewSymbol("profileDisconnected"), Integer::New(7));
    enumObject->Set(String::NewSymbol("registeredRoaming"), Integer::New(8));
    enumObject->Set(String::NewSymbol("registeredHome"), Integer::New(9));
    enumObject->Set(String::NewSymbol("tetheringEntitlementCheck"), Integer::New(10));
    enumObject->Set(String::NewSymbol("tetheringOperationalStateChanged"), Integer::New(11));
    enumObject->Set(String::NewSymbol("tetheringNumberOfClientsChanged"), Integer::New(12));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitMobileBroadbandAccountWatcherStatusEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("MobileBroadbandAccountWatcherStatus"), enumObject);

    enumObject->Set(String::NewSymbol("created"), Integer::New(0));
    enumObject->Set(String::NewSymbol("started"), Integer::New(1));
    enumObject->Set(String::NewSymbol("enumerationCompleted"), Integer::New(2));
    enumObject->Set(String::NewSymbol("stopped"), Integer::New(3));
    enumObject->Set(String::NewSymbol("aborted"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitTetheringOperationalStateEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("TetheringOperationalState"), enumObject);

    enumObject->Set(String::NewSymbol("unknown"), Integer::New(0));
    enumObject->Set(String::NewSymbol("on"), Integer::New(1));
    enumObject->Set(String::NewSymbol("off"), Integer::New(2));
    enumObject->Set(String::NewSymbol("inTransition"), Integer::New(3));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitTetheringCapabilityEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("TetheringCapability"), enumObject);

    enumObject->Set(String::NewSymbol("enabled"), Integer::New(0));
    enumObject->Set(String::NewSymbol("disabledByGroupPolicy"), Integer::New(1));
    enumObject->Set(String::NewSymbol("disabledByHardwareLimitation"), Integer::New(2));
    enumObject->Set(String::NewSymbol("disabledByOperator"), Integer::New(3));
    enumObject->Set(String::NewSymbol("disabledBySku"), Integer::New(4));
    enumObject->Set(String::NewSymbol("disabledByRequiredAppNotInstalled"), Integer::New(5));
    enumObject->Set(String::NewSymbol("disabledDueToUnknownCause"), Integer::New(6));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitTetheringOperationStatusEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("TetheringOperationStatus"), enumObject);

    enumObject->Set(String::NewSymbol("success"), Integer::New(0));
    enumObject->Set(String::NewSymbol("unknown"), Integer::New(1));
    enumObject->Set(String::NewSymbol("mobileBroadbandDeviceOff"), Integer::New(2));
    enumObject->Set(String::NewSymbol("wiFiDeviceOff"), Integer::New(3));
    enumObject->Set(String::NewSymbol("entitlementCheckTimeout"), Integer::New(4));
    enumObject->Set(String::NewSymbol("entitlementCheckFailure"), Integer::New(5));
    enumObject->Set(String::NewSymbol("operationInProgress"), Integer::New(6));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitHotspotAuthenticationResponseCodeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("HotspotAuthenticationResponseCode"), enumObject);

    enumObject->Set(String::NewSymbol("noError"), Integer::New(0));
    enumObject->Set(String::NewSymbol("loginSucceeded"), Integer::New(1));
    enumObject->Set(String::NewSymbol("loginFailed"), Integer::New(2));
    enumObject->Set(String::NewSymbol("radiusServerError"), Integer::New(3));
    enumObject->Set(String::NewSymbol("networkAdministratorError"), Integer::New(4));
    enumObject->Set(String::NewSymbol("loginAborted"), Integer::New(5));
    enumObject->Set(String::NewSymbol("accessGatewayInternalError"), Integer::New(6));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitProfileMediaTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("ProfileMediaType"), enumObject);

    enumObject->Set(String::NewSymbol("wlan"), Integer::New(0));
    enumObject->Set(String::NewSymbol("wwan"), Integer::New(1));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitUssdResultCodeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("UssdResultCode"), enumObject);

    enumObject->Set(String::NewSymbol("noActionRequired"), Integer::New(0));
    enumObject->Set(String::NewSymbol("actionRequired"), Integer::New(1));
    enumObject->Set(String::NewSymbol("terminated"), Integer::New(2));
    enumObject->Set(String::NewSymbol("otherLocalClient"), Integer::New(3));
    enumObject->Set(String::NewSymbol("operationNotSupported"), Integer::New(4));
    enumObject->Set(String::NewSymbol("networkTimeout"), Integer::New(5));

    return scope.Close(Undefined());
  }



  
  static bool IsProfileUsageJsObject(Handle<Value> value)
  {
    if (!value->IsObject())
    {
      return false;
    }

    Handle<String> symbol;
    Handle<Object> obj = value.As<Object>();

    symbol = String::NewSymbol("usageInMegabytes");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("lastSyncTime");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsDate())
      {
          return false;
      }
    }
    
    return true;
  }

  ::Windows::Networking::NetworkOperators::ProfileUsage ProfileUsageFromJsObject(Handle<Value> value)
  {
    HandleScope scope;
    ::Windows::Networking::NetworkOperators::ProfileUsage returnValue;
    
    if (!value->IsObject())
    {
      ThrowException(Exception::TypeError(NodeRT::Utils::NewString(L"Unexpected type, expected an object")));
      return returnValue;
    }

    Handle<Object> obj = value.As<Object>();
    Handle<String> symbol;

    symbol = String::NewSymbol("usageInMegabytes");
    if (obj->Has(symbol))
    {
      returnValue.UsageInMegabytes = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("lastSyncTime");
    if (obj->Has(symbol))
    {
      returnValue.LastSyncTime = NodeRT::Utils::DateTimeFromJSDate(obj->Get(symbol));
    }
    
    return returnValue;
  }

  Handle<Value> ProfileUsageToJsObject(::Windows::Networking::NetworkOperators::ProfileUsage value)
  {
    HandleScope scope;

    Handle<Object> obj = Object::New();

    obj->Set(String::NewSymbol("usageInMegabytes"), Integer::New(value.UsageInMegabytes));
    obj->Set(String::NewSymbol("lastSyncTime"), NodeRT::Utils::DateTimeToJS(value.LastSyncTime));
    
    return scope.Close(obj);
  }

  
  class MobileBroadbandAccount : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandAccount"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getConnectionProfiles"), FunctionTemplate::New(GetConnectionProfiles)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("currentDeviceInformation"), CurrentDeviceInformationGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("currentNetwork"), CurrentNetworkGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAccountId"), NetworkAccountIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serviceProviderGuid"), ServiceProviderGuidGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serviceProviderName"), ServiceProviderNameGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("createFromNetworkAccountId"), FunctionTemplate::New(CreateFromNetworkAccountId)->GetFunction());
      constructor->SetAccessor(String::NewSymbol("availableNetworkAccountIds"), AvailableNetworkAccountIdsGetter);

      exports->Set(String::NewSymbol("MobileBroadbandAccount"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandAccount(::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandAccount^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandAccount *wrapperInstance = new MobileBroadbandAccount(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetConnectionProfiles(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Foundation::Collections::IVectorView<::Windows::Networking::Connectivity::ConnectionProfile^>^ result;
          result = wrapper->_instance->GetConnectionProfiles();
          return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::Networking::Connectivity::ConnectionProfile^>::CreateVectorViewWrapper(result, 
            [](::Windows::Networking::Connectivity::ConnectionProfile^ val) -> Handle<Value> {
              return NodeRT::Utils::CreateExternalWinRTObject("Windows.Networking.Connectivity", "ConnectionProfile", val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::Connectivity::ConnectionProfile^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Networking::Connectivity::ConnectionProfile^ {
              return dynamic_cast<::Windows::Networking::Connectivity::ConnectionProfile^>(NodeRT::Utils::GetObjectInstance(value));
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> CreateFromNetworkAccountId(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ result;
          result = ::Windows::Networking::NetworkOperators::MobileBroadbandAccount::CreateFromNetworkAccountId(arg0);
          return scope.Close(WrapMobileBroadbandAccount(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> CurrentDeviceInformationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ result = wrapper->_instance->CurrentDeviceInformation;
        return scope.Close(WrapMobileBroadbandDeviceInformation(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CurrentNetworkGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ result = wrapper->_instance->CurrentNetwork;
        return scope.Close(WrapMobileBroadbandNetwork(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkAccountIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NetworkAccountId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ServiceProviderGuidGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(info.This());

      try 
      {
        ::Platform::Guid result = wrapper->_instance->ServiceProviderGuid;
        return scope.Close(NodeRT::Utils::GuidToJs(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ServiceProviderNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccount^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccount *wrapper = MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->ServiceProviderName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    

    static Handle<Value> AvailableNetworkAccountIdsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Platform::String^>^ result = ::Windows::Networking::NetworkOperators::MobileBroadbandAccount::AvailableNetworkAccountIds;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Platform::String^>::CreateVectorViewWrapper(result, 
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            },
            [](Handle<Value> value) -> bool {
              return value->IsString();
            },
            [](Handle<Value> value) -> ::Platform::String^ {
              return ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    

  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandAccount(::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ UnwrapMobileBroadbandAccount(Handle<Value> value);
    friend bool IsMobileBroadbandAccountWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandAccount::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandAccount(::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandAccount::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandAccount^ UnwrapMobileBroadbandAccount(Handle<Value> value)
  {
     return MobileBroadbandAccount::Unwrap<MobileBroadbandAccount>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandAccount(Handle<Object> exports)
  {
    MobileBroadbandAccount::Init(exports);
  }

  class MobileBroadbandNetwork : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandNetwork"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("showConnectionUI"), FunctionTemplate::New(ShowConnectionUI)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accessPointName"), AccessPointNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("activationNetworkError"), ActivationNetworkErrorGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAdapter"), NetworkAdapterGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkRegistrationState"), NetworkRegistrationStateGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("packetAttachNetworkError"), PacketAttachNetworkErrorGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("registeredDataClass"), RegisteredDataClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("registeredProviderId"), RegisteredProviderIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("registeredProviderName"), RegisteredProviderNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("registrationNetworkError"), RegistrationNetworkErrorGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("MobileBroadbandNetwork"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandNetwork(::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandNetwork *wrapperInstance = new MobileBroadbandNetwork(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> ShowConnectionUI(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->ShowConnectionUI();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> AccessPointNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->AccessPointName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ActivationNetworkErrorGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ActivationNetworkError;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkAdapterGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        ::Windows::Networking::Connectivity::NetworkAdapter^ result = wrapper->_instance->NetworkAdapter;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Networking.Connectivity", "NetworkAdapter", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkRegistrationStateGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::NetworkRegistrationState result = wrapper->_instance->NetworkRegistrationState;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PacketAttachNetworkErrorGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PacketAttachNetworkError;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RegisteredDataClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::DataClasses result = wrapper->_instance->RegisteredDataClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RegisteredProviderIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->RegisteredProviderId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RegisteredProviderNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->RegisteredProviderName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RegistrationNetworkErrorGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandNetwork *wrapper = MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->RegistrationNetworkError;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandNetwork(::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ UnwrapMobileBroadbandNetwork(Handle<Value> value);
    friend bool IsMobileBroadbandNetworkWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandNetwork::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandNetwork(::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandNetwork::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandNetwork^ UnwrapMobileBroadbandNetwork(Handle<Value> value)
  {
     return MobileBroadbandNetwork::Unwrap<MobileBroadbandNetwork>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandNetwork(Handle<Object> exports)
  {
    MobileBroadbandNetwork::Init(exports);
  }

  class MobileBroadbandDeviceInformation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandDeviceInformation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("cellularClass"), CellularClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("currentRadioState"), CurrentRadioStateGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("customDataClass"), CustomDataClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("dataClasses"), DataClassesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("deviceId"), DeviceIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("deviceType"), DeviceTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firmwareInformation"), FirmwareInformationGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("manufacturer"), ManufacturerGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("mobileEquipmentId"), MobileEquipmentIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("model"), ModelGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkDeviceStatus"), NetworkDeviceStatusGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("simIccId"), SimIccIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("subscriberId"), SubscriberIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("telephoneNumbers"), TelephoneNumbersGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("MobileBroadbandDeviceInformation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandDeviceInformation(::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandDeviceInformation *wrapperInstance = new MobileBroadbandDeviceInformation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> CellularClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Devices::Sms::CellularClass result = wrapper->_instance->CellularClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CurrentRadioStateGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::MobileBroadbandRadioState result = wrapper->_instance->CurrentRadioState;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CustomDataClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->CustomDataClass;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DataClassesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::DataClasses result = wrapper->_instance->DataClasses;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DeviceIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->DeviceId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DeviceTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceType result = wrapper->_instance->DeviceType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FirmwareInformationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->FirmwareInformation;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ManufacturerGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Manufacturer;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MobileEquipmentIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->MobileEquipmentId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ModelGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Model;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkDeviceStatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::NetworkDeviceStatus result = wrapper->_instance->NetworkDeviceStatus;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SimIccIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->SimIccId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SubscriberIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->SubscriberId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TelephoneNumbersGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandDeviceInformation *wrapper = MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IVectorView<::Platform::String^>^ result = wrapper->_instance->TelephoneNumbers;
        return scope.Close(NodeRT::Collections::VectorViewWrapper<::Platform::String^>::CreateVectorViewWrapper(result, 
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            },
            [](Handle<Value> value) -> bool {
              return value->IsString();
            },
            [](Handle<Value> value) -> ::Platform::String^ {
              return ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandDeviceInformation(::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ UnwrapMobileBroadbandDeviceInformation(Handle<Value> value);
    friend bool IsMobileBroadbandDeviceInformationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandDeviceInformation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandDeviceInformation(::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandDeviceInformation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation^ UnwrapMobileBroadbandDeviceInformation(Handle<Value> value)
  {
     return MobileBroadbandDeviceInformation::Unwrap<MobileBroadbandDeviceInformation>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandDeviceInformation(Handle<Object> exports)
  {
    MobileBroadbandDeviceInformation::Init(exports);
  }

  class NetworkOperatorNotificationEventDetails : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("NetworkOperatorNotificationEventDetails"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("authorizeTethering"), FunctionTemplate::New(AuthorizeTethering)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("encodingType"), EncodingTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("message"), MessageGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAccountId"), NetworkAccountIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("notificationType"), NotificationTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ruleId"), RuleIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("smsMessage"), SmsMessageGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("NetworkOperatorNotificationEventDetails"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    NetworkOperatorNotificationEventDetails(::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      NetworkOperatorNotificationEventDetails *wrapperInstance = new NetworkOperatorNotificationEventDetails(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> AuthorizeTethering(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(args.This());

      if (args.Length() == 2
        && args[0]->IsBoolean()
        && args[1]->IsString())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->AuthorizeTethering(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> EncodingTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        unsigned char result = wrapper->_instance->EncodingType;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Message;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkAccountIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NetworkAccountId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NotificationTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::NetworkOperatorEventMessageType result = wrapper->_instance->NotificationType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RuleIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->RuleId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SmsMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorNotificationEventDetails *wrapper = NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(info.This());

      try 
      {
        ::Windows::Devices::Sms::ISmsMessage^ result = wrapper->_instance->SmsMessage;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Devices.Sms", "ISmsMessage", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapNetworkOperatorNotificationEventDetails(::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ UnwrapNetworkOperatorNotificationEventDetails(Handle<Value> value);
    friend bool IsNetworkOperatorNotificationEventDetailsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> NetworkOperatorNotificationEventDetails::s_constructorTemplate;

  v8::Handle<v8::Value> WrapNetworkOperatorNotificationEventDetails(::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(NetworkOperatorNotificationEventDetails::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails^ UnwrapNetworkOperatorNotificationEventDetails(Handle<Value> value)
  {
     return NetworkOperatorNotificationEventDetails::Unwrap<NetworkOperatorNotificationEventDetails>(value.As<Object>())->_instance;
  }

  void InitNetworkOperatorNotificationEventDetails(Handle<Object> exports)
  {
    NetworkOperatorNotificationEventDetails::Init(exports);
  }

  class NetworkOperatorTetheringAccessPointConfiguration : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("NetworkOperatorTetheringAccessPointConfiguration"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ssid"), SsidGetter, SsidSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("passphrase"), PassphraseGetter, PassphraseSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("NetworkOperatorTetheringAccessPointConfiguration"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    NetworkOperatorTetheringAccessPointConfiguration(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      NetworkOperatorTetheringAccessPointConfiguration *wrapperInstance = new NetworkOperatorTetheringAccessPointConfiguration(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> SsidGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringAccessPointConfiguration *wrapper = NetworkOperatorTetheringAccessPointConfiguration::Unwrap<NetworkOperatorTetheringAccessPointConfiguration>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Ssid;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SsidSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(info.This()))
      {
        return;
      }

      NetworkOperatorTetheringAccessPointConfiguration *wrapper = NetworkOperatorTetheringAccessPointConfiguration::Unwrap<NetworkOperatorTetheringAccessPointConfiguration>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Ssid = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> PassphraseGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringAccessPointConfiguration *wrapper = NetworkOperatorTetheringAccessPointConfiguration::Unwrap<NetworkOperatorTetheringAccessPointConfiguration>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Passphrase;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PassphraseSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(info.This()))
      {
        return;
      }

      NetworkOperatorTetheringAccessPointConfiguration *wrapper = NetworkOperatorTetheringAccessPointConfiguration::Unwrap<NetworkOperatorTetheringAccessPointConfiguration>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Passphrase = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapNetworkOperatorTetheringAccessPointConfiguration(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ UnwrapNetworkOperatorTetheringAccessPointConfiguration(Handle<Value> value);
    friend bool IsNetworkOperatorTetheringAccessPointConfigurationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> NetworkOperatorTetheringAccessPointConfiguration::s_constructorTemplate;

  v8::Handle<v8::Value> WrapNetworkOperatorTetheringAccessPointConfiguration(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(NetworkOperatorTetheringAccessPointConfiguration::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ UnwrapNetworkOperatorTetheringAccessPointConfiguration(Handle<Value> value)
  {
     return NetworkOperatorTetheringAccessPointConfiguration::Unwrap<NetworkOperatorTetheringAccessPointConfiguration>(value.As<Object>())->_instance;
  }

  void InitNetworkOperatorTetheringAccessPointConfiguration(Handle<Object> exports)
  {
    NetworkOperatorTetheringAccessPointConfiguration::Init(exports);
  }

  class NetworkOperatorTetheringOperationResult : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("NetworkOperatorTetheringOperationResult"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("additionalErrorMessage"), AdditionalErrorMessageGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("NetworkOperatorTetheringOperationResult"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    NetworkOperatorTetheringOperationResult(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      NetworkOperatorTetheringOperationResult *wrapperInstance = new NetworkOperatorTetheringOperationResult(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> AdditionalErrorMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringOperationResult *wrapper = NetworkOperatorTetheringOperationResult::Unwrap<NetworkOperatorTetheringOperationResult>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->AdditionalErrorMessage;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringOperationResult *wrapper = NetworkOperatorTetheringOperationResult::Unwrap<NetworkOperatorTetheringOperationResult>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::TetheringOperationStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapNetworkOperatorTetheringOperationResult(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ UnwrapNetworkOperatorTetheringOperationResult(Handle<Value> value);
    friend bool IsNetworkOperatorTetheringOperationResultWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> NetworkOperatorTetheringOperationResult::s_constructorTemplate;

  v8::Handle<v8::Value> WrapNetworkOperatorTetheringOperationResult(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(NetworkOperatorTetheringOperationResult::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^ UnwrapNetworkOperatorTetheringOperationResult(Handle<Value> value)
  {
     return NetworkOperatorTetheringOperationResult::Unwrap<NetworkOperatorTetheringOperationResult>(value.As<Object>())->_instance;
  }

  void InitNetworkOperatorTetheringOperationResult(Handle<Object> exports)
  {
    NetworkOperatorTetheringOperationResult::Init(exports);
  }

  class NetworkOperatorTetheringManager : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("NetworkOperatorTetheringManager"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentAccessPointConfiguration"), FunctionTemplate::New(GetCurrentAccessPointConfiguration)->GetFunction());
      
            
      func = FunctionTemplate::New(ConfigureAccessPointAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("configureAccessPointAsync"), func);
      func = FunctionTemplate::New(StartTetheringAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("startTetheringAsync"), func);
      func = FunctionTemplate::New(StopTetheringAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("stopTetheringAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("clientCount"), ClientCountGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("maxClientCount"), MaxClientCountGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("tetheringOperationalState"), TetheringOperationalStateGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getTetheringCapability"), FunctionTemplate::New(GetTetheringCapability)->GetFunction());
      constructor->Set(String::NewSymbol("createFromNetworkAccountId"), FunctionTemplate::New(CreateFromNetworkAccountId)->GetFunction());

      exports->Set(String::NewSymbol("NetworkOperatorTetheringManager"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    NetworkOperatorTetheringManager(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      NetworkOperatorTetheringManager *wrapperInstance = new NetworkOperatorTetheringManager(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> ConfigureAccessPointAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(args.This());

      ::Windows::Foundation::IAsyncAction^ op;
    

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^>(args[0]))
      {
        try
        {
          ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ arg0 = UnwrapNetworkOperatorTetheringAccessPointConfiguration(args[0]);
          
          op = wrapper->_instance->ConfigureAccessPointAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> StartTetheringAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->StartTetheringAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapNetworkOperatorTetheringOperationResult(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> StopTetheringAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->StopTetheringAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapNetworkOperatorTetheringOperationResult(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> GetCurrentAccessPointConfiguration(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration^ result;
          result = wrapper->_instance->GetCurrentAccessPointConfiguration();
          return scope.Close(WrapNetworkOperatorTetheringAccessPointConfiguration(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetTetheringCapability(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::TetheringCapability result;
          result = ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager::GetTetheringCapability(arg0);
          return scope.Close(Integer::New(static_cast<int>(result)));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateFromNetworkAccountId(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ result;
          result = ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager::CreateFromNetworkAccountId(arg0);
          return scope.Close(WrapNetworkOperatorTetheringManager(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ClientCountGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ClientCount;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MaxClientCountGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MaxClientCount;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TetheringOperationalStateGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      NetworkOperatorTetheringManager *wrapper = NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::TetheringOperationalState result = wrapper->_instance->TetheringOperationalState;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapNetworkOperatorTetheringManager(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ UnwrapNetworkOperatorTetheringManager(Handle<Value> value);
    friend bool IsNetworkOperatorTetheringManagerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> NetworkOperatorTetheringManager::s_constructorTemplate;

  v8::Handle<v8::Value> WrapNetworkOperatorTetheringManager(::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(NetworkOperatorTetheringManager::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager^ UnwrapNetworkOperatorTetheringManager(Handle<Value> value)
  {
     return NetworkOperatorTetheringManager::Unwrap<NetworkOperatorTetheringManager>(value.As<Object>())->_instance;
  }

  void InitNetworkOperatorTetheringManager(Handle<Object> exports)
  {
    NetworkOperatorTetheringManager::Init(exports);
  }

  class MobileBroadbandAccountEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandAccountEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAccountId"), NetworkAccountIdGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("MobileBroadbandAccountEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandAccountEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandAccountEventArgs *wrapperInstance = new MobileBroadbandAccountEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> NetworkAccountIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountEventArgs *wrapper = MobileBroadbandAccountEventArgs::Unwrap<MobileBroadbandAccountEventArgs>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NetworkAccountId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandAccountEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ UnwrapMobileBroadbandAccountEventArgs(Handle<Value> value);
    friend bool IsMobileBroadbandAccountEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandAccountEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandAccountEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandAccountEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ UnwrapMobileBroadbandAccountEventArgs(Handle<Value> value)
  {
     return MobileBroadbandAccountEventArgs::Unwrap<MobileBroadbandAccountEventArgs>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandAccountEventArgs(Handle<Object> exports)
  {
    MobileBroadbandAccountEventArgs::Init(exports);
  }

  class MobileBroadbandAccountUpdatedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandAccountUpdatedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("hasDeviceInformationChanged"), HasDeviceInformationChangedGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("hasNetworkChanged"), HasNetworkChangedGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAccountId"), NetworkAccountIdGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("MobileBroadbandAccountUpdatedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandAccountUpdatedEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandAccountUpdatedEventArgs *wrapperInstance = new MobileBroadbandAccountUpdatedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> HasDeviceInformationChangedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountUpdatedEventArgs *wrapper = MobileBroadbandAccountUpdatedEventArgs::Unwrap<MobileBroadbandAccountUpdatedEventArgs>(info.This());

      try 
      {
        bool result = wrapper->_instance->HasDeviceInformationChanged;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HasNetworkChangedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountUpdatedEventArgs *wrapper = MobileBroadbandAccountUpdatedEventArgs::Unwrap<MobileBroadbandAccountUpdatedEventArgs>(info.This());

      try 
      {
        bool result = wrapper->_instance->HasNetworkChanged;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkAccountIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountUpdatedEventArgs *wrapper = MobileBroadbandAccountUpdatedEventArgs::Unwrap<MobileBroadbandAccountUpdatedEventArgs>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NetworkAccountId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandAccountUpdatedEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ UnwrapMobileBroadbandAccountUpdatedEventArgs(Handle<Value> value);
    friend bool IsMobileBroadbandAccountUpdatedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandAccountUpdatedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandAccountUpdatedEventArgs(::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandAccountUpdatedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ UnwrapMobileBroadbandAccountUpdatedEventArgs(Handle<Value> value)
  {
     return MobileBroadbandAccountUpdatedEventArgs::Unwrap<MobileBroadbandAccountUpdatedEventArgs>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandAccountUpdatedEventArgs(Handle<Object> exports)
  {
    MobileBroadbandAccountUpdatedEventArgs::Init(exports);
  }

  class MobileBroadbandAccountWatcher : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("MobileBroadbandAccountWatcher"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("start"), FunctionTemplate::New(Start)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("stop"), FunctionTemplate::New(Stop)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("MobileBroadbandAccountWatcher"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    MobileBroadbandAccountWatcher(::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      MobileBroadbandAccountWatcher *wrapperInstance = new MobileBroadbandAccountWatcher(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> Start(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Start();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Stop(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Stop();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcherStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"accountAdded", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->AccountAdded::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^>(
            [callbackObjPtr](::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ arg0, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapMobileBroadbandAccountWatcher(arg0);
                Handle<Value> wrappedArg1 = WrapMobileBroadbandAccountEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"accountRemoved", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->AccountRemoved::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^>(
            [callbackObjPtr](::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ arg0, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapMobileBroadbandAccountWatcher(arg0);
                Handle<Value> wrappedArg1 = WrapMobileBroadbandAccountEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"accountUpdated", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->AccountUpdated::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^>(
            [callbackObjPtr](::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ arg0, ::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapMobileBroadbandAccountWatcher(arg0);
                Handle<Value> wrappedArg1 = WrapMobileBroadbandAccountUpdatedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"enumerationCompleted", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->EnumerationCompleted::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^, ::Platform::Object^>(
            [callbackObjPtr](::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ arg0, ::Platform::Object^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapMobileBroadbandAccountWatcher(arg0);
                Handle<Value> wrappedArg1 = CreateOpaqueWrapper(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"stopped", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->Stopped::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^, ::Platform::Object^>(
            [callbackObjPtr](::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ arg0, ::Platform::Object^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapMobileBroadbandAccountWatcher(arg0);
                Handle<Value> wrappedArg1 = CreateOpaqueWrapper(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"accountAdded", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"accountRemoved", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"accountUpdated", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"enumerationCompleted", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"stopped", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"accountAdded", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
          wrapper->_instance->AccountAdded::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"accountRemoved", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
          wrapper->_instance->AccountRemoved::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"accountUpdated", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
          wrapper->_instance->AccountUpdated::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"enumerationCompleted", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
          wrapper->_instance->EnumerationCompleted::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"stopped", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          MobileBroadbandAccountWatcher *wrapper = MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(args.This());
          wrapper->_instance->Stopped::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapMobileBroadbandAccountWatcher(::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ UnwrapMobileBroadbandAccountWatcher(Handle<Value> value);
    friend bool IsMobileBroadbandAccountWatcherWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> MobileBroadbandAccountWatcher::s_constructorTemplate;

  v8::Handle<v8::Value> WrapMobileBroadbandAccountWatcher(::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(MobileBroadbandAccountWatcher::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher^ UnwrapMobileBroadbandAccountWatcher(Handle<Value> value)
  {
     return MobileBroadbandAccountWatcher::Unwrap<MobileBroadbandAccountWatcher>(value.As<Object>())->_instance;
  }

  void InitMobileBroadbandAccountWatcher(Handle<Object> exports)
  {
    MobileBroadbandAccountWatcher::Init(exports);
  }

  class HotspotAuthenticationEventDetails : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("HotspotAuthenticationEventDetails"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("eventToken"), EventTokenGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("HotspotAuthenticationEventDetails"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    HotspotAuthenticationEventDetails(::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      HotspotAuthenticationEventDetails *wrapperInstance = new HotspotAuthenticationEventDetails(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> EventTokenGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationEventDetails *wrapper = HotspotAuthenticationEventDetails::Unwrap<HotspotAuthenticationEventDetails>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->EventToken;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapHotspotAuthenticationEventDetails(::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ UnwrapHotspotAuthenticationEventDetails(Handle<Value> value);
    friend bool IsHotspotAuthenticationEventDetailsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> HotspotAuthenticationEventDetails::s_constructorTemplate;

  v8::Handle<v8::Value> WrapHotspotAuthenticationEventDetails(::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(HotspotAuthenticationEventDetails::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails^ UnwrapHotspotAuthenticationEventDetails(Handle<Value> value)
  {
     return HotspotAuthenticationEventDetails::Unwrap<HotspotAuthenticationEventDetails>(value.As<Object>())->_instance;
  }

  void InitHotspotAuthenticationEventDetails(Handle<Object> exports)
  {
    HotspotAuthenticationEventDetails::Init(exports);
  }

  class HotspotAuthenticationContext : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("HotspotAuthenticationContext"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("issueCredentials"), FunctionTemplate::New(IssueCredentials)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("abortAuthentication"), FunctionTemplate::New(AbortAuthentication)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("skipAuthentication"), FunctionTemplate::New(SkipAuthentication)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("triggerAttentionRequired"), FunctionTemplate::New(TriggerAttentionRequired)->GetFunction());
      
            
      func = FunctionTemplate::New(IssueCredentialsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("issueCredentialsAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("authenticationUrl"), AuthenticationUrlGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("networkAdapter"), NetworkAdapterGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("redirectMessageUrl"), RedirectMessageUrlGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("redirectMessageXml"), RedirectMessageXmlGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("wirelessNetworkId"), WirelessNetworkIdGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("tryGetAuthenticationContext"), FunctionTemplate::New(TryGetAuthenticationContext)->GetFunction());

      exports->Set(String::NewSymbol("HotspotAuthenticationContext"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    HotspotAuthenticationContext(::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      HotspotAuthenticationContext *wrapperInstance = new HotspotAuthenticationContext(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> IssueCredentialsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>^ op;
    

      if (args.Length() == 5
        && args[0]->IsString()
        && args[1]->IsString()
        && args[2]->IsString()
        && args[3]->IsBoolean())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          bool arg3 = args[3]->BooleanValue();
          
          op = wrapper->_instance->IssueCredentialsAsync(arg0,arg1,arg2,arg3);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapHotspotCredentialsAuthenticationResult(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> IssueCredentials(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(args.This());

      if (args.Length() == 4
        && args[0]->IsString()
        && args[1]->IsString()
        && args[2]->IsString()
        && args[3]->IsBoolean())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          bool arg3 = args[3]->BooleanValue();
          
          wrapper->_instance->IssueCredentials(arg0, arg1, arg2, arg3);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AbortAuthentication(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          wrapper->_instance->AbortAuthentication(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SkipAuthentication(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->SkipAuthentication();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> TriggerAttentionRequired(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->TriggerAttentionRequired(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> TryGetAuthenticationContext(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ arg1;  
          
          bool result;
          result = ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext::TryGetAuthenticationContext(arg0, &arg1);
          Handle<Object> resObj = Object::New();
          resObj->Set(String::NewSymbol("boolean"), Boolean::New(result));
          resObj->Set(String::NewSymbol("context"), NodeRT::Utils::CreateExternalWinRTObject("Windows.Networking.NetworkOperators", "HotspotAuthenticationContext", arg1));
          return scope.Close(resObj);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> AuthenticationUrlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->AuthenticationUrl;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NetworkAdapterGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(info.This());

      try 
      {
        ::Windows::Networking::Connectivity::NetworkAdapter^ result = wrapper->_instance->NetworkAdapter;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Networking.Connectivity", "NetworkAdapter", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RedirectMessageUrlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->RedirectMessageUrl;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RedirectMessageXmlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->RedirectMessageXml;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Data.Xml.Dom", "XmlDocument", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> WirelessNetworkIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotAuthenticationContext *wrapper = HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(info.This());

      try 
      {
        ::Platform::Array<unsigned char>^ result = wrapper->_instance->WirelessNetworkId;
        return scope.Close(NodeRT::Collections::ArrayWrapper<unsigned char>::CreateArrayWrapper(result, 
            [](unsigned char val) -> Handle<Value> {
              return Integer::New(val);
            },
            [](Handle<Value> value) -> bool {
              return value->IsInt32();
            },
            [](Handle<Value> value) -> unsigned char {
              return static_cast<unsigned char>(value->Int32Value());
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapHotspotAuthenticationContext(::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ UnwrapHotspotAuthenticationContext(Handle<Value> value);
    friend bool IsHotspotAuthenticationContextWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> HotspotAuthenticationContext::s_constructorTemplate;

  v8::Handle<v8::Value> WrapHotspotAuthenticationContext(::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(HotspotAuthenticationContext::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::HotspotAuthenticationContext^ UnwrapHotspotAuthenticationContext(Handle<Value> value)
  {
     return HotspotAuthenticationContext::Unwrap<HotspotAuthenticationContext>(value.As<Object>())->_instance;
  }

  void InitHotspotAuthenticationContext(Handle<Object> exports)
  {
    HotspotAuthenticationContext::Init(exports);
  }

  class HotspotCredentialsAuthenticationResult : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("HotspotCredentialsAuthenticationResult"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("authenticationReplyXml"), AuthenticationReplyXmlGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("hasNetworkErrorOccurred"), HasNetworkErrorOccurredGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("logoffUrl"), LogoffUrlGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("responseCode"), ResponseCodeGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("HotspotCredentialsAuthenticationResult"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    HotspotCredentialsAuthenticationResult(::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      HotspotCredentialsAuthenticationResult *wrapperInstance = new HotspotCredentialsAuthenticationResult(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> AuthenticationReplyXmlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotCredentialsAuthenticationResult *wrapper = HotspotCredentialsAuthenticationResult::Unwrap<HotspotCredentialsAuthenticationResult>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->AuthenticationReplyXml;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Data.Xml.Dom", "XmlDocument", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HasNetworkErrorOccurredGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotCredentialsAuthenticationResult *wrapper = HotspotCredentialsAuthenticationResult::Unwrap<HotspotCredentialsAuthenticationResult>(info.This());

      try 
      {
        bool result = wrapper->_instance->HasNetworkErrorOccurred;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LogoffUrlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotCredentialsAuthenticationResult *wrapper = HotspotCredentialsAuthenticationResult::Unwrap<HotspotCredentialsAuthenticationResult>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->LogoffUrl;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ResponseCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      HotspotCredentialsAuthenticationResult *wrapper = HotspotCredentialsAuthenticationResult::Unwrap<HotspotCredentialsAuthenticationResult>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::HotspotAuthenticationResponseCode result = wrapper->_instance->ResponseCode;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapHotspotCredentialsAuthenticationResult(::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ UnwrapHotspotCredentialsAuthenticationResult(Handle<Value> value);
    friend bool IsHotspotCredentialsAuthenticationResultWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> HotspotCredentialsAuthenticationResult::s_constructorTemplate;

  v8::Handle<v8::Value> WrapHotspotCredentialsAuthenticationResult(::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(HotspotCredentialsAuthenticationResult::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult^ UnwrapHotspotCredentialsAuthenticationResult(Handle<Value> value)
  {
     return HotspotCredentialsAuthenticationResult::Unwrap<HotspotCredentialsAuthenticationResult>(value.As<Object>())->_instance;
  }

  void InitHotspotCredentialsAuthenticationResult(Handle<Object> exports)
  {
    HotspotCredentialsAuthenticationResult::Init(exports);
  }

  class ProvisionFromXmlDocumentResults : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ProvisionFromXmlDocumentResults"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("allElementsProvisioned"), AllElementsProvisionedGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("provisionResultsXml"), ProvisionResultsXmlGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ProvisionFromXmlDocumentResults"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ProvisionFromXmlDocumentResults(::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ProvisionFromXmlDocumentResults *wrapperInstance = new ProvisionFromXmlDocumentResults(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> AllElementsProvisionedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ProvisionFromXmlDocumentResults *wrapper = ProvisionFromXmlDocumentResults::Unwrap<ProvisionFromXmlDocumentResults>(info.This());

      try 
      {
        bool result = wrapper->_instance->AllElementsProvisioned;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ProvisionResultsXmlGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ProvisionFromXmlDocumentResults *wrapper = ProvisionFromXmlDocumentResults::Unwrap<ProvisionFromXmlDocumentResults>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->ProvisionResultsXml;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapProvisionFromXmlDocumentResults(::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ UnwrapProvisionFromXmlDocumentResults(Handle<Value> value);
    friend bool IsProvisionFromXmlDocumentResultsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ProvisionFromXmlDocumentResults::s_constructorTemplate;

  v8::Handle<v8::Value> WrapProvisionFromXmlDocumentResults(::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ProvisionFromXmlDocumentResults::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^ UnwrapProvisionFromXmlDocumentResults(Handle<Value> value)
  {
     return ProvisionFromXmlDocumentResults::Unwrap<ProvisionFromXmlDocumentResults>(value.As<Object>())->_instance;
  }

  void InitProvisionFromXmlDocumentResults(Handle<Object> exports)
  {
    ProvisionFromXmlDocumentResults::Init(exports);
  }

  class ProvisionedProfile : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ProvisionedProfile"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("updateCost"), FunctionTemplate::New(UpdateCost)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("updateUsage"), FunctionTemplate::New(UpdateUsage)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ProvisionedProfile"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ProvisionedProfile(::Windows::Networking::NetworkOperators::ProvisionedProfile^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::ProvisionedProfile^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionedProfile^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::ProvisionedProfile^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ProvisionedProfile *wrapperInstance = new ProvisionedProfile(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> UpdateCost(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionedProfile^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ProvisionedProfile *wrapper = ProvisionedProfile::Unwrap<ProvisionedProfile>(args.This());

      if (args.Length() == 1
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::Networking::Connectivity::NetworkCostType arg0 = static_cast<::Windows::Networking::Connectivity::NetworkCostType>(args[0]->Int32Value());
          
          wrapper->_instance->UpdateCost(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> UpdateUsage(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisionedProfile^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ProvisionedProfile *wrapper = ProvisionedProfile::Unwrap<ProvisionedProfile>(args.This());

      if (args.Length() == 1
        && IsProfileUsageJsObject(args[0]))
      {
        try
        {
          ::Windows::Networking::NetworkOperators::ProfileUsage arg0 = ProfileUsageFromJsObject(args[0]);
          
          wrapper->_instance->UpdateUsage(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Networking::NetworkOperators::ProvisionedProfile^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapProvisionedProfile(::Windows::Networking::NetworkOperators::ProvisionedProfile^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::ProvisionedProfile^ UnwrapProvisionedProfile(Handle<Value> value);
    friend bool IsProvisionedProfileWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ProvisionedProfile::s_constructorTemplate;

  v8::Handle<v8::Value> WrapProvisionedProfile(::Windows::Networking::NetworkOperators::ProvisionedProfile^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ProvisionedProfile::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::ProvisionedProfile^ UnwrapProvisionedProfile(Handle<Value> value)
  {
     return ProvisionedProfile::Unwrap<ProvisionedProfile>(value.As<Object>())->_instance;
  }

  void InitProvisionedProfile(Handle<Object> exports)
  {
    ProvisionedProfile::Init(exports);
  }

  class ProvisioningAgent : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ProvisioningAgent"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getProvisionedProfile"), FunctionTemplate::New(GetProvisionedProfile)->GetFunction());
      
            
      func = FunctionTemplate::New(ProvisionFromXmlDocumentAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("provisionFromXmlDocumentAsync"), func);
      
                  
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("createFromNetworkAccountId"), FunctionTemplate::New(CreateFromNetworkAccountId)->GetFunction());

      exports->Set(String::NewSymbol("ProvisioningAgent"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ProvisioningAgent(::Windows::Networking::NetworkOperators::ProvisioningAgent^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::ProvisioningAgent^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisioningAgent^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::ProvisioningAgent^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::NetworkOperators::ProvisioningAgent();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ProvisioningAgent *wrapperInstance = new ProvisioningAgent(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> ProvisionFromXmlDocumentAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisioningAgent^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ProvisioningAgent *wrapper = ProvisioningAgent::Unwrap<ProvisioningAgent>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^>^ op;
    

      if (args.Length() == 2
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          op = wrapper->_instance->ProvisionFromXmlDocumentAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapProvisionFromXmlDocumentResults(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> GetProvisionedProfile(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::ProvisioningAgent^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ProvisioningAgent *wrapper = ProvisioningAgent::Unwrap<ProvisioningAgent>(args.This());

      if (args.Length() == 2
        && args[0]->IsInt32()
        && args[1]->IsString())
      {
        try
        {
          ::Windows::Networking::NetworkOperators::ProfileMediaType arg0 = static_cast<::Windows::Networking::NetworkOperators::ProfileMediaType>(args[0]->Int32Value());
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Networking::NetworkOperators::ProvisionedProfile^ result;
          result = wrapper->_instance->GetProvisionedProfile(arg0, arg1);
          return scope.Close(WrapProvisionedProfile(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> CreateFromNetworkAccountId(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::ProvisioningAgent^ result;
          result = ::Windows::Networking::NetworkOperators::ProvisioningAgent::CreateFromNetworkAccountId(arg0);
          return scope.Close(WrapProvisioningAgent(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



  private:
    ::Windows::Networking::NetworkOperators::ProvisioningAgent^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapProvisioningAgent(::Windows::Networking::NetworkOperators::ProvisioningAgent^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::ProvisioningAgent^ UnwrapProvisioningAgent(Handle<Value> value);
    friend bool IsProvisioningAgentWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ProvisioningAgent::s_constructorTemplate;

  v8::Handle<v8::Value> WrapProvisioningAgent(::Windows::Networking::NetworkOperators::ProvisioningAgent^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ProvisioningAgent::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::ProvisioningAgent^ UnwrapProvisioningAgent(Handle<Value> value)
  {
     return ProvisioningAgent::Unwrap<ProvisioningAgent>(value.As<Object>())->_instance;
  }

  void InitProvisioningAgent(Handle<Object> exports)
  {
    ProvisioningAgent::Init(exports);
  }

  class UssdMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("UssdMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getPayload"), FunctionTemplate::New(GetPayload)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setPayload"), FunctionTemplate::New(SetPayload)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("payloadAsText"), PayloadAsTextGetter, PayloadAsTextSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("dataCodingScheme"), DataCodingSchemeGetter, DataCodingSchemeSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("UssdMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    UssdMessage(::Windows::Networking::NetworkOperators::UssdMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::UssdMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::UssdMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          winRtInstance = ref new ::Windows::Networking::NetworkOperators::UssdMessage(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      UssdMessage *wrapperInstance = new UssdMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetPayload(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Platform::Array<unsigned char>^ result;
          result = wrapper->_instance->GetPayload();
          return scope.Close(NodeRT::Collections::ArrayWrapper<unsigned char>::CreateArrayWrapper(result, 
            [](unsigned char val) -> Handle<Value> {
              return Integer::New(val);
            },
            [](Handle<Value> value) -> bool {
              return value->IsInt32();
            },
            [](Handle<Value> value) -> unsigned char {
              return static_cast<unsigned char>(value->Int32Value());
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetPayload(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(args.This());

      if (args.Length() == 1
        && (NodeRT::Utils::IsWinRtWrapperOf<::Platform::Array<unsigned char>^>(args[0]) || args[0]->IsArray()))
      {
        try
        {
          ::Platform::Array<unsigned char>^ arg0 = 
            [] (v8::Handle<v8::Value> value) -> ::Platform::Array<unsigned char>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtArray<unsigned char>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return value->IsInt32();
                 },
                 [](Handle<Value> value) -> unsigned char {
                   return static_cast<unsigned char>(value->Int32Value());
                 }
                );
              }
              else
              {
                return dynamic_cast<::Platform::Array<unsigned char>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[0]);
          
          wrapper->_instance->SetPayload(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> PayloadAsTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->PayloadAsText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PayloadAsTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(info.This()))
      {
        return;
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->PayloadAsText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> DataCodingSchemeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(info.This());

      try 
      {
        unsigned char result = wrapper->_instance->DataCodingScheme;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataCodingSchemeSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(info.This()))
      {
        return;
      }

      UssdMessage *wrapper = UssdMessage::Unwrap<UssdMessage>(info.This());

      try 
      {
        
        unsigned char winRtValue = static_cast<unsigned char>(value->Int32Value());

        wrapper->_instance->DataCodingScheme = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::UssdMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapUssdMessage(::Windows::Networking::NetworkOperators::UssdMessage^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::UssdMessage^ UnwrapUssdMessage(Handle<Value> value);
    friend bool IsUssdMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> UssdMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapUssdMessage(::Windows::Networking::NetworkOperators::UssdMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(UssdMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::UssdMessage^ UnwrapUssdMessage(Handle<Value> value)
  {
     return UssdMessage::Unwrap<UssdMessage>(value.As<Object>())->_instance;
  }

  void InitUssdMessage(Handle<Object> exports)
  {
    UssdMessage::Init(exports);
  }

  class UssdReply : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("UssdReply"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("message"), MessageGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("resultCode"), ResultCodeGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("UssdReply"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    UssdReply(::Windows::Networking::NetworkOperators::UssdReply^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::UssdReply^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdReply^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::UssdReply^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      UssdReply *wrapperInstance = new UssdReply(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> MessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdReply^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UssdReply *wrapper = UssdReply::Unwrap<UssdReply>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::UssdMessage^ result = wrapper->_instance->Message;
        return scope.Close(WrapUssdMessage(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ResultCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdReply^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UssdReply *wrapper = UssdReply::Unwrap<UssdReply>(info.This());

      try 
      {
        ::Windows::Networking::NetworkOperators::UssdResultCode result = wrapper->_instance->ResultCode;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::NetworkOperators::UssdReply^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapUssdReply(::Windows::Networking::NetworkOperators::UssdReply^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::UssdReply^ UnwrapUssdReply(Handle<Value> value);
    friend bool IsUssdReplyWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> UssdReply::s_constructorTemplate;

  v8::Handle<v8::Value> WrapUssdReply(::Windows::Networking::NetworkOperators::UssdReply^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(UssdReply::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::UssdReply^ UnwrapUssdReply(Handle<Value> value)
  {
     return UssdReply::Unwrap<UssdReply>(value.As<Object>())->_instance;
  }

  void InitUssdReply(Handle<Object> exports)
  {
    UssdReply::Init(exports);
  }

  class UssdSession : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("UssdSession"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
            
      func = FunctionTemplate::New(SendMessageAndGetReplyAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("sendMessageAndGetReplyAsync"), func);
      
                  
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("createFromNetworkAccountId"), FunctionTemplate::New(CreateFromNetworkAccountId)->GetFunction());
      constructor->Set(String::NewSymbol("createFromNetworkInterfaceId"), FunctionTemplate::New(CreateFromNetworkInterfaceId)->GetFunction());

      exports->Set(String::NewSymbol("UssdSession"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    UssdSession(::Windows::Networking::NetworkOperators::UssdSession^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::NetworkOperators::UssdSession^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdSession^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::NetworkOperators::UssdSession^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      UssdSession *wrapperInstance = new UssdSession(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> SendMessageAndGetReplyAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdSession^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      UssdSession *wrapper = UssdSession::Unwrap<UssdSession>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::NetworkOperators::UssdReply^>^ op;
    

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdMessage^>(args[0]))
      {
        try
        {
          ::Windows::Networking::NetworkOperators::UssdMessage^ arg0 = UnwrapUssdMessage(args[0]);
          
          op = wrapper->_instance->SendMessageAndGetReplyAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::NetworkOperators::UssdReply^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUssdReply(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::NetworkOperators::UssdSession^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      UssdSession *wrapper = UssdSession::Unwrap<UssdSession>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> CreateFromNetworkAccountId(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::UssdSession^ result;
          result = ::Windows::Networking::NetworkOperators::UssdSession::CreateFromNetworkAccountId(arg0);
          return scope.Close(WrapUssdSession(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateFromNetworkInterfaceId(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::NetworkOperators::UssdSession^ result;
          result = ::Windows::Networking::NetworkOperators::UssdSession::CreateFromNetworkInterfaceId(arg0);
          return scope.Close(WrapUssdSession(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



  private:
    ::Windows::Networking::NetworkOperators::UssdSession^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapUssdSession(::Windows::Networking::NetworkOperators::UssdSession^ wintRtInstance);
    friend ::Windows::Networking::NetworkOperators::UssdSession^ UnwrapUssdSession(Handle<Value> value);
    friend bool IsUssdSessionWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> UssdSession::s_constructorTemplate;

  v8::Handle<v8::Value> WrapUssdSession(::Windows::Networking::NetworkOperators::UssdSession^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(UssdSession::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::NetworkOperators::UssdSession^ UnwrapUssdSession(Handle<Value> value)
  {
     return UssdSession::Unwrap<UssdSession>(value.As<Object>())->_instance;
  }

  void InitUssdSession(Handle<Object> exports)
  {
    UssdSession::Init(exports);
  }

} } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::Networking::NetworkOperators::InitDataClassesEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandDeviceTypeEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkDeviceStatusEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkRegistrationStateEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandRadioStateEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkOperatorEventMessageTypeEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandAccountWatcherStatusEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitTetheringOperationalStateEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitTetheringCapabilityEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitTetheringOperationStatusEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitHotspotAuthenticationResponseCodeEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitProfileMediaTypeEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitUssdResultCodeEnum(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandAccount(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandNetwork(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandDeviceInformation(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkOperatorNotificationEventDetails(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkOperatorTetheringAccessPointConfiguration(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkOperatorTetheringOperationResult(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitNetworkOperatorTetheringManager(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandAccountEventArgs(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandAccountUpdatedEventArgs(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitMobileBroadbandAccountWatcher(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitHotspotAuthenticationEventDetails(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitHotspotAuthenticationContext(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitHotspotCredentialsAuthenticationResult(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitProvisionFromXmlDocumentResults(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitProvisionedProfile(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitProvisioningAgent(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitUssdMessage(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitUssdReply(exports);
  NodeRT::Windows::Networking::NetworkOperators::InitUssdSession(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.Networking.NetworkOperators", exports);
}


NODE_MODULE(binding, init)